@@ -7,7 +7,7 @@ class Ops():
     """Class for making operations on pd.DataFrames."""
 
     @staticmethod
-    def remove_null_values(self, df: pd.DataFrame) -> pd.DataFrame:
+    def remove_null_values(df: pd.DataFrame) -> pd.DataFrame:
         """Remove all rows containing null values in the dataframe.
 
         Args:
@@ -22,7 +22,7 @@ class Ops():
         return df
 
     @staticmethod
-    def rotate(self, df: pd.DataFrame, xx: str, yy: str, scalars: str) -> pd.DataFrame:
+    def rotate(df: pd.DataFrame, xx: str, yy: str, scalars: str) -> pd.DataFrame:
         """Remove missing values and rotate the dataframe using the pivot function.
 
         Args:
@@ -34,5 +34,5 @@ class Ops():
         Returns:
             pd.DataFrame: reshaped dataframe.
         """
-        df = self.remove_null_values(df=df)
+        df = Ops.remove_null_values(df=df)
         return df.pivot(index=xx, columns=yy, values=scalars)
